@@ -1,8 +1,8 @@
 import re
 import sys
 from textwrap import dedent
+from unittest import mock
 
-import mock
 import pytest
 from discord import Colour
 
